# EchidnaLib

Modern and modular open source python package used to create discord bots.

## About The Project

The goal of this project is to implement an easy to use system which can dynamically add commands and functionality to Discord Bots.  
I also plan to include a way to manage and control bots through the console during runtime.

## Installation

You can install the current version using "python -m pip install echidnalib"

<!-- ROADMAP -->
## Roadmap

See the [open issues](https://github.com/IdleEchidna/EchidnaLib/issues) for a list of proposed features (and known issues).



<!-- CONTRIBUTING -->
## Contributing

Contributions are what make the open source community such an amazing place to be learn, inspire, and create. Any contributions you make are **greatly appreciated**.

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request



<!-- LICENSE -->
## License

Distributed under the MIT License. See `LICENSE` for more information.


<!-- ACKNOWLEDGEMENTS -->
## Acknowledgements
* [discord.py](https://github.com/Rapptz/discord.py)
